@@ -148,34 +148,24 @@ def config_loader(config_file=None, dataset=None):
     Returns: a the dataset value or the config as dictionary
 
     """
+    default_config = dict(MissionSupportSystemDefaultConfig.__dict__)
+    if dataset is not None and dataset not in default_config:
+        raise KeyError(f"requested dataset '{dataset}' not in defaults!")
     if config_file is None:
         config_file = constants.CACHED_CONFIG_FILE
     if config_file is None:
         logging.info(
             'Default MSS configuration in place, no user settings, see http://mss.rtfd.io/en/stable/usage.html')
-    default_config = dict(MissionSupportSystemDefaultConfig.__dict__)
-    if dataset is not None and dataset not in default_config:
-        raise KeyError(f"requested dataset '{dataset}' not in defaults or config_file")
-    if config_file is None:
         if dataset is None:
             return default_config
         else:
             return default_config[dataset]
     user_config = read_config_file(config_file)
     if dataset is not None:
-        if dataset not in user_config:
-            return default_config[dataset]
-        else:
-            return user_config[dataset]
+        return user_config.get(dataset, default_config[dataset])
     else:
-        for key in user_config:
-            default_config[key] = user_config[key]
+        default_config.update(user_config)
         return default_config
-    if len(user_config) == 0:
-        if dataset is None:
-            return default_config
-        else:
-            return default_config[dataset]
 
 
 def get_distance(coord0, coord1):
@@ -457,14 +447,13 @@ def interpolate_vertsec(data3D, data3D_lats, data3D_lons, lats, lons):
     # parameter controls the degree of the splines used, i.e. order=1
     # stands for linear interpolation.
     for ml in range(data3D.shape[0]):
-        data = data3D[ml, :, :]
-        curtain[ml, :] = map_coordinates(data, ind_coords, order=1)
+        curtain[ml, :] = map_coordinates(data3D[ml, :, :].filled(np.nan), ind_coords, order=1)
 
     curtain[:, np.isnan(ind_lats) | np.isnan(ind_lons)] = np.nan
     return np.ma.masked_invalid(curtain)
 
 
-def latlon_points(p1, p2, numpoints=100, connection='linear'):
+def latlon_points(p1, p2, numpoints=100, connection='linear', contains_altitude=False):
     """
     Compute intermediate points between two given points.
 
@@ -478,8 +467,9 @@ def latlon_points(p1, p2, numpoints=100, connection='linear'):
     """
     LAT = 0
     LON = 1
-    TIME = 2
-    lats, lons, times = None, None, None
+    ALT = 2
+    TIME = 2 if not contains_altitude else 3
+    lats, lons, alts, times = None, None, None, None
 
     if connection == 'linear':
         lats = np.linspace(p1[LAT], p2[LAT], numpoints)
@@ -494,13 +484,19 @@ def latlon_points(p1, p2, numpoints=100, connection='linear'):
             lats = np.asarray([p1[LAT], p2[LAT]])
             lons = np.asarray([p1[LON], p2[LON]])
 
+    if contains_altitude:
+        alts = np.linspace(p1[ALT], p2[ALT], numpoints)
+
     p1_time, p2_time = nc.date2num([p1[TIME], p2[TIME]], "seconds since 2000-01-01")
     times = np.linspace(p1_time, p2_time, numpoints)
 
-    return lats, lons, nc.num2date(times, "seconds since 2000-01-01")
+    if not contains_altitude:
+        return lats, lons, nc.num2date(times, "seconds since 2000-01-01")
+    else:
+        return lats, lons, alts, nc.num2date(times, "seconds since 2000-01-01")
 
 
-def path_points(points, numpoints=100, connection='linear'):
+def path_points(points, numpoints=100, connection='linear', contains_altitude=False):
     """
     Compute intermediate points of a path given by a list of points.
 
@@ -514,9 +510,13 @@ def path_points(points, numpoints=100, connection='linear'):
     """
     if connection not in ['linear', 'greatcircle']:
         return None, None
+    if points is None or len(points) == 0:
+        return None, None, None
+
     LAT = 0
     LON = 1
-    TIME = 2
+    ALT = 2
+    TIME = 3 if contains_altitude else 2
 
     # First compute the lengths of the individual path segments, i.e.
     # the distances between the points.
@@ -544,7 +544,11 @@ def path_points(points, numpoints=100, connection='linear'):
         lons = np.repeat(points[0][LON], numpoints)
         lats = np.repeat(points[0][LAT], numpoints)
         times = np.repeat(points[0][TIME], numpoints)
-        return lats, lons, times
+        if contains_altitude:
+            alts = np.repeat(points[0][ALT], numpoints)
+            return lats, lons, alts, times
+        else:
+            return lats, lons, times
 
     # For each segment, determine the number of points to be computed
     # from the distance between the two bounding points and the
@@ -553,6 +557,7 @@ def path_points(points, numpoints=100, connection='linear'):
     # first segment to avoid double points.
     lons = []
     lats = []
+    alts = []
     times = []
     for i in range(len(points) - 1):
         segment_points = int(round(distances[i] / length_point_segment))
@@ -560,14 +565,24 @@ def path_points(points, numpoints=100, connection='linear'):
         # (otherwise latlon_points will throw an exception).
         segment_points = max(segment_points, 2)
         # print segment_points
-        lats_, lons_, times_ = latlon_points(
-            points[i], points[i + 1],
-            numpoints=segment_points, connection=connection)
+        if not contains_altitude:
+            lats_, lons_, times_ = latlon_points(
+                points[i], points[i + 1],
+                numpoints=segment_points, connection=connection)
+        else:
+            lats_, lons_, alts_, times_ = latlon_points(
+                points[i], points[i + 1],
+                numpoints=segment_points, connection=connection, contains_altitude=True)
         startidx = 0 if i == 0 else 1
         lons.extend(lons_[startidx:])
         lats.extend(lats_[startidx:])
         times.extend(times_[startidx:])
-    return [np.asarray(_x) for _x in (lats, lons, times)]
+        if contains_altitude:
+            alts.extend(alts_[startidx:])
+
+    if not contains_altitude:
+        return [np.asarray(_x) for _x in (lats, lons, times)]
+    return [np.asarray(_x) for _x in (lats, lons, alts, times)]
 
 
 def convert_pressure_to_vertical_axis_measure(vertical_axis, pressure):
@@ -589,10 +604,10 @@ def convert_pressure_to_vertical_axis_measure(vertical_axis, pressure):
 
 def convert_to(value, from_unit, to_unit, default=1.):
     try:
-        value_unit = UR.Quantity(value, UR(from_unit))
+        value_unit = UR.Quantity(value, from_unit)
         result = value_unit.to(to_unit).magnitude
     except pint.UndefinedUnitError:
-        logging.error("Error in unit conversion (undefined) %s/%s", from_unit, to_unit)
+        logging.error("Error in unit conversion (undefined) '%s'/'%s'", from_unit, to_unit)
         result = value * default
     except pint.DimensionalityError:
         if UR(to_unit).to_base_units().units == UR.m:
